pm4py.statistics.start\_activities.log package
==============================================

Submodules
----------

pm4py.statistics.start\_activities.log.get module
-------------------------------------------------

.. automodule:: pm4py.statistics.start_activities.log.get
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.statistics.start_activities.log
   :members:
   :undoc-members:
   :show-inheritance:
